@@ -2,7 +2,7 @@
 """
 
 #
-# Copyright (c) 2001 - 2016 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 # 
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -24,11 +24,13 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/packaging/ipk.py rel_2.5.1:3735:9dc6cee5c168 2016/11/03 14:02:02 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/packaging/ipk.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+
+import os
 
 import SCons.Builder
 import SCons.Node.FS
-import os
+import SCons.Util
 
 from SCons.Tool.packaging import stripinstallbuilder, putintopackageroot
 
@@ -119,7 +121,9 @@ def build_specfiles(source, target, env):
         try:
             return opened_files[needle]
         except KeyError:
-            file=filter(lambda x: x.get_path().rfind(needle)!=-1, haystack)[0]
+            files = filter(lambda x: x.get_path().rfind(needle) != -1, haystack)
+            # Py3: filter returns an iterable, not a list
+            file = list(files)[0]
             opened_files[needle]=open(file.get_abspath(), 'w')
             return opened_files[needle]
 
@@ -169,7 +173,7 @@ Description: $X_IPK_DESCRIPTION
 
     #
     # close all opened files
-    for f in opened_files.values():
+    for f in list(opened_files.values()):
         f.close()
 
     # call a user specified function
