@@ -10,7 +10,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -33,7 +33,7 @@ selection method.
 #
 from __future__ import print_function
 
-__revision__ = "src/engine/SCons/Tool/tex.py rel_3.0.0:4395:8972f6a2f699 2017/09/18 12:59:24 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/tex.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
 
 import os.path
 import re
@@ -790,7 +790,7 @@ def tex_emitter_core(target, source, env, graphics_extensions):
                 for multibibmatch in multibib_re.finditer(content):
                     if Verbose:
                         print("multibib match ",multibibmatch.group(1))
-                    if multibibmatch != None:
+                    if multibibmatch is not None:
                         baselist = multibibmatch.group(1).split(',')
                         if Verbose:
                             print("multibib list ", baselist)
